.. app_name documentation master file, created by
   sphinx-quickstart on Thu Jul 30 10:15:34 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 1
   :caption: Contents:


.. toctree::
   :caption: Getting started
   :name: getting_started
   :hidden:
   :maxdepth: 1

   getting_started/installation

.. toctree::
  :caption: Usage 
  :name: usage
  :hidden:
  :maxdepth: 1

  usage/app_cli
  usage/snakemake_cli


 

